# HG changeset patch
# User David Holsgrove <david.holsgrove@xilinx.com>
# Date 1350459158 -36000
# Node ID e0d7ed57abba06e0f0932944a1edba48dbb02489
# Parent  480239e52f550835988fcb6a19dc4392b0bd4624
binutils/binutils: Add CUSTOM version and CUSTOM_LOCATION config options and GetCustom

CUSTOM_LOCATION config options only presented in menuconfig if component
CUSTOM version selected.

Signed-off-by: "David Holsgrove" <david.holsgrove@xilinx.com>

diff -r 480239e52f55 -r e0d7ed57abba config/binutils/binutils.in
--- a/config/binutils/binutils.in	Wed Oct 17 17:32:38 2012 +1000
+++ b/config/binutils/binutils.in	Wed Oct 17 17:32:38 2012 +1000
@@ -50,8 +50,26 @@
     prompt "2.16.1a (OBSOLETE)"
     depends on OBSOLETE
 
+config BINUTILS_CUSTOM
+    bool
+    prompt "Custom binutils"
+    depends on EXPERIMENTAL
+    select BINUTILS_2_22_or_later
+
 endchoice
 
+if BINUTILS_CUSTOM
+
+config BINUTILS_CUSTOM_LOCATION
+    string
+    prompt "Full path to custom binutils source"
+    default ""
+    help
+      Enter the path to the directory (or tarball) of your source for binutils,
+      or leave blank to use default CT_CUSTOM_LOCATION_ROOT_DIR/binutils
+
+endif # BINUTILS_CUSTOM
+
 config BINUTILS_VERSION
     string
 # Don't remove next line
@@ -64,6 +82,7 @@
     default "2.18a" if BINUTILS_V_2_18a
     default "2.17a" if BINUTILS_V_2_17a
     default "2.16.1a" if BINUTILS_V_2_16_1a
+    default "custom" if BINUTILS_CUSTOM
 
 config BINUTILS_2_22_or_later
     bool
diff -r 480239e52f55 -r e0d7ed57abba scripts/build/binutils/binutils.sh
--- a/scripts/build/binutils/binutils.sh	Wed Oct 17 17:32:38 2012 +1000
+++ b/scripts/build/binutils/binutils.sh	Wed Oct 17 17:32:38 2012 +1000
@@ -4,15 +4,27 @@
 
 # Download binutils
 do_binutils_get() {
-    CT_GetFile "binutils-${CT_BINUTILS_VERSION}"                                        \
-               {ftp,http}://{ftp.gnu.org/gnu,ftp.kernel.org/pub/linux/devel}/binutils   \
-               ftp://gcc.gnu.org/pub/binutils/{releases,snapshots}
+    if [ "${CT_BINUTILS_CUSTOM}" = "y" ]; then
+        CT_GetCustom "binutils" "${CT_BINUTILS_VERSION}" \
+        "${CT_BINUTILS_CUSTOM_LOCATION}"
+    else
+        CT_GetFile "binutils-${CT_BINUTILS_VERSION}"                                        \
+                   {ftp,http}://{ftp.gnu.org/gnu,ftp.kernel.org/pub/linux/devel}/binutils   \
+                   ftp://gcc.gnu.org/pub/binutils/{releases,snapshots}
+    fi
 }
 
 # Extract binutils
 do_binutils_extract() {
-    CT_Extract "binutils-${CT_BINUTILS_VERSION}"
-    CT_Patch "binutils" "${CT_BINUTILS_VERSION}"
+    # Attempt CT_EXTRACT only if NOT custom, or CUSTOM_LOCATION is not a directory
+    if [ "${CT_BINUTILS_CUSTOM}" != "y" \
+         -o ! -d "${CT_SRC_DIR}/binutils-${CT_BINUTILS_VERSION}" ]; then
+        CT_Extract "binutils-${CT_BINUTILS_VERSION}"
+    fi
+    # Attempt CT_PATCH only if NOT custom
+    if [ "${CT_BINUTILS_CUSTOM}" != "y" ]; then
+        CT_Patch "binutils" "${CT_BINUTILS_VERSION}"
+    fi
 }
 
 # Build binutils for build -> target
